=========================
ptyx module documentation
=========================

.. automodule:: ptyx
.. autoclass:: LatexGenerator
    :members:
.. autoclass:: CustomOutput
    :members:
.. autoclass:: SpecialDict
    :members:
.. autoclass:: Node
    :members:
.. autoclass:: SyntaxTreeGenerator
    :members:

